@@ -23,6 +23,7 @@ from variety.Util import Util
 from variety_lib import varietyconfig
 
 import logging
+from variety import _str
 
 logger = logging.getLogger('variety')
 
@@ -36,7 +37,6 @@ class Options:
         FOLDER = 2
         FAVORITES = 3
         FETCHED = 4
-        WN = 5
         DESKTOPPR = 6
         FLICKR = 7
         APOD = 8
@@ -56,7 +56,6 @@ class Options:
             FETCHED: "fetched",
             IMAGE: "image",
             FOLDER: "folder",
-            WN: "wn",
             DESKTOPPR: "desktoppr",
             FLICKR: "flickr",
             APOD: "apod",
@@ -74,7 +73,7 @@ class Options:
 
         str_to_type = dict((v,k) for k, v in type_to_str.items())
 
-        dl_types = [WN, DESKTOPPR, FLICKR, APOD, WALLBASE, MEDIA_RSS, EARTH,
+        dl_types = [DESKTOPPR, FLICKR, APOD, WALLBASE, MEDIA_RSS, EARTH,
                     PANORAMIO, WALLHAVEN, REDDIT, BING, UNSPLASH, RECOMMENDED, LATEST]
 
     class LightnessMode:
@@ -387,6 +386,78 @@ class Options:
             except Exception:
                 pass
 
+            try:
+                self.slideshow_sources_enabled = config["slideshow_sources_enabled"].lower() in TRUTH_VALUES
+            except Exception:
+                pass
+
+            try:
+                self.slideshow_favorites_enabled = config["slideshow_favorites_enabled"].lower() in TRUTH_VALUES
+            except Exception:
+                pass
+
+            try:
+                self.slideshow_downloads_enabled = config["slideshow_downloads_enabled"].lower() in TRUTH_VALUES
+            except Exception:
+                pass
+
+            try:
+                self.slideshow_custom_enabled = config["slideshow_custom_enabled"].lower() in TRUTH_VALUES
+            except Exception:
+                pass
+
+            try:
+                custom_path = config["slideshow_custom_folder"]
+                if custom_path in ('None', 'Default') or not os.path.isdir():
+                    self.slideshow_custom_folder = Util.get_xdg_pictures_folder()
+                else:
+                    self.slideshow_custom_folder = custom_path
+            except Exception:
+                pass
+
+            try:
+                slideshow_sort_order = config["slideshow_sort_order"]
+                if slideshow_sort_order in ["Random", "Name, asc", "Name, desc", "Date, asc", "Date, desc"]:
+                    self.slideshow_sort_order = slideshow_sort_order
+            except Exception:
+                pass
+
+            try:
+                self.slideshow_monitor = config["slideshow_monitor"]
+            except Exception:
+                pass
+
+            try:
+                slideshow_mode = config["slideshow_mode"]
+                if slideshow_mode in ["Fullscreen", "Desktop", "Maximized", "Window"]:
+                    self.slideshow_mode = slideshow_mode
+            except Exception:
+                pass
+
+            try:
+                self.slideshow_seconds = float(config["slideshow_seconds"])
+                self.slideshow_seconds = max(0.5, self.slideshow_seconds)
+            except Exception:
+                pass
+
+            try:
+                self.slideshow_fade = float(config["slideshow_fade"])
+                self.slideshow_fade = max(0, min(1, self.slideshow_fade))
+            except Exception:
+                pass
+
+            try:
+                self.slideshow_zoom = float(config["slideshow_zoom"])
+                self.slideshow_zoom = max(0, min(1, self.slideshow_zoom))
+            except Exception:
+                pass
+
+            try:
+                self.slideshow_pan = float(config["slideshow_pan"])
+                self.slideshow_pan = max(0, min(0.20, self.slideshow_pan))
+            except Exception:
+                pass
+
             if "sources" in config:
                 self.sources = []
                 sources = config["sources"]
@@ -424,7 +495,7 @@ class Options:
         changed = False
         for key, outdated_hashes in Options.OUTDATED_HASHES.items():
             if key in config:
-                current_hash = hashlib.md5(config[key]).hexdigest()
+                current_hash = hashlib.md5(_str(config[key])).hexdigest()
                 if current_hash in outdated_hashes:
                     # entry is outdated: delete it and use the default
                     logger.warning(lambda: "Option " + key + " has an outdated value, using the new default")
@@ -553,6 +624,18 @@ class Options:
         self.quotes_vpos = 40
         self.quotes_favorites_file = os.path.expanduser(u"~/.config/variety/favorite_quotes.txt")
 
+        self.slideshow_sources_enabled = True
+        self.slideshow_favorites_enabled = True
+        self.slideshow_downloads_enabled = False
+        self.slideshow_custom_enabled = False
+        self.slideshow_custom_folder = Util.get_xdg_pictures_folder()
+        self.slideshow_sort_order = "Random"
+        self.slideshow_monitor = "All"
+        self.slideshow_mode = "Fullscreen"
+        self.slideshow_seconds = 6
+        self.slideshow_fade = 0.4
+        self.slideshow_zoom = 0.2
+        self.slideshow_pan = 0.05
 
         self.sources = [
             [True, Options.SourceType.FAVORITES, "The Favorites folder"],
@@ -562,7 +645,6 @@ class Options:
             [True, Options.SourceType.BING, "Bing Photo of the Day"],
             [True, Options.SourceType.UNSPLASH, "High-resolution photos from Unsplash.com"],
             [False, Options.SourceType.APOD, "NASA's Astronomy Picture of the Day"],
-            [True, Options.SourceType.WN, "http://wallpapers.net/nature-desktop-wallpapers.html"],
             [True, Options.SourceType.FLICKR, "user:www.flickr.com/photos/peter-levi/;user_id:93647178@N00;"],
             [True, Options.SourceType.WALLHAVEN, "nature"],
         ]
@@ -652,6 +734,19 @@ class Options:
             config["quotes_vpos"] = str(self.quotes_vpos)
             config["quotes_favorites_file"] = Util.collapseuser(self.quotes_favorites_file)
 
+            config["slideshow_sources_enabled"] = str(self.slideshow_sources_enabled)
+            config["slideshow_favorites_enabled"] = str(self.slideshow_favorites_enabled)
+            config["slideshow_downloads_enabled"] = str(self.slideshow_downloads_enabled)
+            config["slideshow_custom_enabled"] = str(self.slideshow_custom_enabled)
+            config["slideshow_custom_folder"] = Util.collapseuser(self.slideshow_custom_folder)
+            config["slideshow_sort_order"] = self.slideshow_sort_order
+            config["slideshow_monitor"] = self.slideshow_monitor
+            config["slideshow_mode"] = self.slideshow_mode
+            config["slideshow_seconds"] = str(self.slideshow_seconds)
+            config["slideshow_fade"] = str(self.slideshow_fade)
+            config["slideshow_zoom"] = str(self.slideshow_zoom)
+            config["slideshow_pan"] = str(self.slideshow_pan)
+
             config["sources"] = {}
             for i, s in enumerate(self.sources):
                 config["sources"]["src" + str(i + 1)] = str(s[0]) + "|" + str(Options.type_to_str(s[1])) + "|" + s[2]
