@@ -266,6 +266,19 @@ class Indicator:
         self.downloads_handler_id = self.downloads.connect("toggled", window.show_hide_downloads)
         self.menu.append(self.downloads)
 
+        try:
+            from varietyslideshow import varietyslideshow
+        except:
+            logger.warning('Variety Slideshow is not installed. '
+                           'Install it with "sudo apt-get install variety-slideshow", '
+                           'read more here: http://peterlevi.com/variety/slideshow/')
+        else:
+            self.menu.append(Gtk.SeparatorMenuItem.new())
+
+            self.slideshow = Gtk.MenuItem(_("Start Slideshow"))
+            self.slideshow.connect("activate", window.on_start_slideshow)
+            self.menu.append(self.slideshow)
+
         self.menu.append(Gtk.SeparatorMenuItem.new())
 
         self.preferences = Gtk.MenuItem(_("Preferences..."))
@@ -273,9 +286,13 @@ class Indicator:
         self.menu.append(self.preferences)
 
         self.about = Gtk.MenuItem(_("About"))
-        self.about.connect("activate",window.on_mnu_about_activate)
+        self.about.connect("activate", window.on_mnu_about_activate)
         self.menu.append(self.about)
 
+        self.donate = Gtk.MenuItem(_("Donate"))
+        self.donate.connect("activate", window.on_mnu_donate_activate)
+        self.menu.append(self.donate)
+
         self.quit = Gtk.MenuItem(_("Quit"))
         self.quit.connect("activate",window.on_quit)
         self.menu.append(self.quit)
